@@ -23,8 +23,7 @@ from typing import Any, Iterator, List, Mapping, Sequence, Set, Union
 
 from boto3.dynamodb.conditions import ConditionBase
 from boto3.dynamodb.table import BatchWriter
-from boto3.resources.base import ResourceMeta
-from boto3.resources.base import ServiceResource as Boto3ServiceResource
+from boto3.resources.base import ResourceMeta, ServiceResource
 from boto3.resources.collection import ResourceCollection
 
 from .client import DynamoDBClient
@@ -40,39 +39,44 @@ from .literals import (
 )
 from .type_defs import (
     ArchivalSummaryResponseMetadataTypeDef,
-    AttributeDefinitionTypeDef,
-    AttributeValueUpdateTypeDef,
-    BatchGetItemOutputTypeDef,
-    BatchWriteItemOutputTypeDef,
+    AttributeDefinitionServiceResourceTypeDef,
+    AttributeDefinitionTableTypeDef,
+    AttributeValueUpdateTableTypeDef,
+    BatchGetItemOutputServiceResourceTypeDef,
+    BatchWriteItemOutputServiceResourceTypeDef,
     BillingModeSummaryResponseMetadataTypeDef,
-    ConditionTypeDef,
-    DeleteItemOutputTypeDef,
-    DeleteTableOutputTypeDef,
-    ExpectedAttributeValueTypeDef,
-    GetItemOutputTypeDef,
-    GlobalSecondaryIndexDescriptionTypeDef,
-    GlobalSecondaryIndexTypeDef,
-    GlobalSecondaryIndexUpdateTypeDef,
-    KeysAndAttributesTypeDef,
-    KeySchemaElementTypeDef,
-    LocalSecondaryIndexDescriptionTypeDef,
-    LocalSecondaryIndexTypeDef,
+    ConditionTableTypeDef,
+    DeleteItemOutputTableTypeDef,
+    DeleteTableOutputTableTypeDef,
+    ExpectedAttributeValueTableTypeDef,
+    GetItemOutputTableTypeDef,
+    GlobalSecondaryIndexDescriptionTableTypeDef,
+    GlobalSecondaryIndexServiceResourceTypeDef,
+    GlobalSecondaryIndexUpdateTableTypeDef,
+    KeysAndAttributesServiceResourceTypeDef,
+    KeySchemaElementServiceResourceTypeDef,
+    KeySchemaElementTableTypeDef,
+    LocalSecondaryIndexDescriptionTableTypeDef,
+    LocalSecondaryIndexServiceResourceTypeDef,
     ProvisionedThroughputDescriptionResponseMetadataTypeDef,
-    ProvisionedThroughputTypeDef,
-    PutItemOutputTypeDef,
-    QueryOutputTypeDef,
-    ReplicaDescriptionTypeDef,
-    ReplicationGroupUpdateTypeDef,
+    ProvisionedThroughputServiceResourceTypeDef,
+    ProvisionedThroughputTableTypeDef,
+    PutItemOutputTableTypeDef,
+    QueryOutputTableTypeDef,
+    ReplicaDescriptionTableTypeDef,
+    ReplicationGroupUpdateTableTypeDef,
     RestoreSummaryResponseMetadataTypeDef,
-    ScanOutputTypeDef,
+    ScanOutputTableTypeDef,
     SSEDescriptionResponseMetadataTypeDef,
-    SSESpecificationTypeDef,
+    SSESpecificationServiceResourceTypeDef,
+    SSESpecificationTableTypeDef,
     StreamSpecificationResponseMetadataTypeDef,
-    StreamSpecificationTypeDef,
+    StreamSpecificationServiceResourceTypeDef,
+    StreamSpecificationTableTypeDef,
     TableClassSummaryResponseMetadataTypeDef,
-    TagTypeDef,
-    UpdateItemOutputTypeDef,
-    WriteRequestTypeDef,
+    TagServiceResourceTypeDef,
+    UpdateItemOutputTableTypeDef,
+    WriteRequestServiceResourceTypeDef,
 )
 
 __all__ = ("DynamoDBServiceResource", "Table", "ServiceResourceTablesCollection")
@@ -135,15 +139,15 @@ class ServiceResourceTablesCollection(ResourceCollection):
         """
 
 
-class Table(Boto3ServiceResource):
+class Table(ServiceResource):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource/#table)
     """
 
-    attribute_definitions: List["AttributeDefinitionTypeDef"]
+    attribute_definitions: List[AttributeDefinitionTableTypeDef]
     table_name: str
-    key_schema: List["KeySchemaElementTypeDef"]
+    key_schema: List[KeySchemaElementTableTypeDef]
     table_status: TableStatusType
     creation_date_time: datetime
     provisioned_throughput: ProvisionedThroughputDescriptionResponseMetadataTypeDef
@@ -152,13 +156,13 @@ class Table(Boto3ServiceResource):
     table_arn: str
     table_id: str
     billing_mode_summary: BillingModeSummaryResponseMetadataTypeDef
-    local_secondary_indexes: List["LocalSecondaryIndexDescriptionTypeDef"]
-    global_secondary_indexes: List["GlobalSecondaryIndexDescriptionTypeDef"]
+    local_secondary_indexes: List[LocalSecondaryIndexDescriptionTableTypeDef]
+    global_secondary_indexes: List[GlobalSecondaryIndexDescriptionTableTypeDef]
     stream_specification: StreamSpecificationResponseMetadataTypeDef
     latest_stream_label: str
     latest_stream_arn: str
     global_table_version: str
-    replicas: List["ReplicaDescriptionTypeDef"]
+    replicas: List[ReplicaDescriptionTableTypeDef]
     restore_summary: RestoreSummaryResponseMetadataTypeDef
     sse_description: SSEDescriptionResponseMetadataTypeDef
     archival_summary: ArchivalSummaryResponseMetadataTypeDef
@@ -173,7 +177,7 @@ class Table(Boto3ServiceResource):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource/#tablebatch_writer-method)
         """
 
-    def delete(self) -> DeleteTableOutputTypeDef:
+    def delete(self) -> DeleteTableOutputTableTypeDef:
         """
         The `DeleteTable` operation deletes a table and all of its items.
 
@@ -203,12 +207,12 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ],
-        Expected: Mapping[str, "ExpectedAttributeValueTypeDef"] = ...,
+        Expected: Mapping[str, ExpectedAttributeValueTableTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ReturnValues: ReturnValueType = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
-        ConditionExpression: str = ...,
+        ConditionExpression: Union[str, ConditionBase] = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
         ExpressionAttributeValues: Mapping[
             str,
@@ -229,7 +233,7 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ] = ...
-    ) -> DeleteItemOutputTypeDef:
+    ) -> DeleteItemOutputTableTypeDef:
         """
         Deletes a single item in a table by primary key.
 
@@ -272,7 +276,7 @@ class Table(Boto3ServiceResource):
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ProjectionExpression: str = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...
-    ) -> GetItemOutputTypeDef:
+    ) -> GetItemOutputTableTypeDef:
         """
         The `GetItem` operation returns a set of attributes for the item with the given
         primary key.
@@ -312,12 +316,12 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ],
-        Expected: Mapping[str, "ExpectedAttributeValueTypeDef"] = ...,
+        Expected: Mapping[str, ExpectedAttributeValueTableTypeDef] = ...,
         ReturnValues: ReturnValueType = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
-        ConditionExpression: str = ...,
+        ConditionExpression: Union[str, ConditionBase] = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
         ExpressionAttributeValues: Mapping[
             str,
@@ -338,7 +342,7 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ] = ...
-    ) -> PutItemOutputTypeDef:
+    ) -> PutItemOutputTableTypeDef:
         """
         Creates a new item, or replaces an old item with a new item.
 
@@ -354,8 +358,8 @@ class Table(Boto3ServiceResource):
         AttributesToGet: Sequence[str] = ...,
         Limit: int = ...,
         ConsistentRead: bool = ...,
-        KeyConditions: Mapping[str, "ConditionTypeDef"] = ...,
-        QueryFilter: Mapping[str, "ConditionTypeDef"] = ...,
+        KeyConditions: Mapping[str, ConditionTableTypeDef] = ...,
+        QueryFilter: Mapping[str, ConditionTableTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ScanIndexForward: bool = ...,
         ExclusiveStartKey: Mapping[
@@ -401,7 +405,7 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ] = ...
-    ) -> QueryOutputTypeDef:
+    ) -> QueryOutputTableTypeDef:
         """
         You must provide the name of the partition key attribute and a single value for
         that attribute.
@@ -426,7 +430,7 @@ class Table(Boto3ServiceResource):
         AttributesToGet: Sequence[str] = ...,
         Limit: int = ...,
         Select: SelectType = ...,
-        ScanFilter: Mapping[str, "ConditionTypeDef"] = ...,
+        ScanFilter: Mapping[str, ConditionTableTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ExclusiveStartKey: Mapping[
             str,
@@ -473,7 +477,7 @@ class Table(Boto3ServiceResource):
             ],
         ] = ...,
         ConsistentRead: bool = ...
-    ) -> ScanOutputTypeDef:
+    ) -> ScanOutputTableTypeDef:
         """
         The `Scan` operation returns one or more items and item attributes by accessing
         every item in a table or a secondary index.
@@ -485,13 +489,13 @@ class Table(Boto3ServiceResource):
     def update(
         self,
         *,
-        AttributeDefinitions: Sequence["AttributeDefinitionTypeDef"] = ...,
+        AttributeDefinitions: Sequence[AttributeDefinitionTableTypeDef] = ...,
         BillingMode: BillingModeType = ...,
-        ProvisionedThroughput: "ProvisionedThroughputTypeDef" = ...,
-        GlobalSecondaryIndexUpdates: Sequence["GlobalSecondaryIndexUpdateTypeDef"] = ...,
-        StreamSpecification: "StreamSpecificationTypeDef" = ...,
-        SSESpecification: "SSESpecificationTypeDef" = ...,
-        ReplicaUpdates: Sequence["ReplicationGroupUpdateTypeDef"] = ...,
+        ProvisionedThroughput: ProvisionedThroughputTableTypeDef = ...,
+        GlobalSecondaryIndexUpdates: Sequence[GlobalSecondaryIndexUpdateTableTypeDef] = ...,
+        StreamSpecification: StreamSpecificationTableTypeDef = ...,
+        SSESpecification: SSESpecificationTableTypeDef = ...,
+        ReplicaUpdates: Sequence[ReplicationGroupUpdateTableTypeDef] = ...,
         TableClass: TableClassType = ...
     ) -> "_Table":
         """
@@ -524,14 +528,14 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ],
-        AttributeUpdates: Mapping[str, "AttributeValueUpdateTypeDef"] = ...,
-        Expected: Mapping[str, "ExpectedAttributeValueTypeDef"] = ...,
+        AttributeUpdates: Mapping[str, AttributeValueUpdateTableTypeDef] = ...,
+        Expected: Mapping[str, ExpectedAttributeValueTableTypeDef] = ...,
         ConditionalOperator: ConditionalOperatorType = ...,
         ReturnValues: ReturnValueType = ...,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...,
         UpdateExpression: str = ...,
-        ConditionExpression: str = ...,
+        ConditionExpression: Union[str, ConditionBase] = ...,
         ExpressionAttributeNames: Mapping[str, str] = ...,
         ExpressionAttributeValues: Mapping[
             str,
@@ -552,7 +556,7 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ] = ...
-    ) -> UpdateItemOutputTypeDef:
+    ) -> UpdateItemOutputTableTypeDef:
         """
         Edits an existing item's attributes, or adds a new item to the table if it does
         not already exist.
@@ -585,7 +589,7 @@ class DynamoDBResourceMeta(ResourceMeta):
     client: DynamoDBClient
 
 
-class DynamoDBServiceResource(Boto3ServiceResource):
+class DynamoDBServiceResource(ServiceResource):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.ServiceResource)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource/)
@@ -605,9 +609,9 @@ class DynamoDBServiceResource(Boto3ServiceResource):
     def batch_get_item(
         self,
         *,
-        RequestItems: Mapping[str, "KeysAndAttributesTypeDef"],
+        RequestItems: Mapping[str, KeysAndAttributesServiceResourceTypeDef],
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...
-    ) -> BatchGetItemOutputTypeDef:
+    ) -> BatchGetItemOutputServiceResourceTypeDef:
         """
         The `BatchGetItem` operation returns the attributes of one or more items from
         one or more tables.
@@ -619,10 +623,10 @@ class DynamoDBServiceResource(Boto3ServiceResource):
     def batch_write_item(
         self,
         *,
-        RequestItems: Mapping[str, Sequence["WriteRequestTypeDef"]],
+        RequestItems: Mapping[str, Sequence[WriteRequestServiceResourceTypeDef]],
         ReturnConsumedCapacity: ReturnConsumedCapacityType = ...,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = ...
-    ) -> BatchWriteItemOutputTypeDef:
+    ) -> BatchWriteItemOutputServiceResourceTypeDef:
         """
         The `BatchWriteItem` operation puts or deletes multiple items in one or more
         tables.
@@ -634,16 +638,16 @@ class DynamoDBServiceResource(Boto3ServiceResource):
     def create_table(
         self,
         *,
-        AttributeDefinitions: Sequence["AttributeDefinitionTypeDef"],
+        AttributeDefinitions: Sequence[AttributeDefinitionServiceResourceTypeDef],
         TableName: str,
-        KeySchema: Sequence["KeySchemaElementTypeDef"],
-        LocalSecondaryIndexes: Sequence["LocalSecondaryIndexTypeDef"] = ...,
-        GlobalSecondaryIndexes: Sequence["GlobalSecondaryIndexTypeDef"] = ...,
+        KeySchema: Sequence[KeySchemaElementServiceResourceTypeDef],
+        LocalSecondaryIndexes: Sequence[LocalSecondaryIndexServiceResourceTypeDef] = ...,
+        GlobalSecondaryIndexes: Sequence[GlobalSecondaryIndexServiceResourceTypeDef] = ...,
         BillingMode: BillingModeType = ...,
-        ProvisionedThroughput: "ProvisionedThroughputTypeDef" = ...,
-        StreamSpecification: "StreamSpecificationTypeDef" = ...,
-        SSESpecification: "SSESpecificationTypeDef" = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        ProvisionedThroughput: ProvisionedThroughputServiceResourceTypeDef = ...,
+        StreamSpecification: StreamSpecificationServiceResourceTypeDef = ...,
+        SSESpecification: SSESpecificationServiceResourceTypeDef = ...,
+        Tags: Sequence[TagServiceResourceTypeDef] = ...,
         TableClass: TableClassType = ...
     ) -> _Table:
         """
